@@ -1,12 +1,14 @@
 import pandas as pd
 from typing_extensions import Self
+from typing_extensions import overload
 
-from klass.classes.correspondence import KlassCorrespondence
-from klass.classes.variant import KlassVariant
-from klass.requests.klass_requests import version_by_id
-from klass.requests.klass_types import CorrespondenceTablesType
-from klass.requests.klass_types import VersionByIDType
-from klass.utility.naming import create_shortname
+from ..requests.klass_requests import version_by_id
+from ..requests.klass_types import CorrespondenceTablesType
+from ..requests.klass_types import Language
+from ..requests.klass_types import VersionByIDType
+from ..utility.naming import create_shortname
+from .correspondence import KlassCorrespondence
+from .variant import KlassVariant
 
 
 class KlassVersion:
@@ -30,17 +32,17 @@ class KlassVersion:
         correspondenceTables (list): A list of correspondence-tables of the version.
 
     Args:
-        version_id (str): The ID of the version.
-        select_level (int): The level in the codelist-data to keep. Defaults to 0 (keep all).
-        language (str, optional): The language of the version. Defaults to "nb", can be set to "en", or "nn".
-        include_future (bool, optional): If the version should include future versions. Defaults to False.
+        version_id: The ID of the version.
+        select_level: The level in the codelist-data to keep. Defaults to 0 (keep all).
+        language: The language of the version. Defaults to "nb", can be set to "en", or "nn".
+        include_future: If the version should include future versions. Defaults to False.
     """
 
     def __init__(
         self,
-        version_id: str,
-        select_level: int = 0,
-        language: str = "nb",
+        version_id: str | int,
+        select_level: int | None = None,
+        language: Language = "nb",
         include_future: bool = False,
     ) -> None:
         """Set up the object with data from the KLASS-API."""
@@ -128,19 +130,18 @@ class KlassVersion:
         )
         return result
 
-    def get_classification_codes(self, select_level: int = 0) -> Self:
+    def get_classification_codes(self, select_level: int | None = None) -> Self:
         """Get the codelists of the version. Inserts the result into the KlassVersions .data attribute, instead of returning it.
 
         Run as a part of the class initialization.
 
         Args:
-            select_level (int): The level of the version to keep in the data. Setting to 0 keeps all levels.
+            select_level: The level of the version to keep in the data. Setting to 0 keeps all levels.
 
         Returns:
             self (KlassVersion): Returns self to make the method more easily chainable.
         """
-        if not select_level and self.select_level:
-            select_level = self.select_level
+        select_level = select_level if select_level else self.select_level
         data = pd.json_normalize(self.classificationItems)
         level_map = {
             str(item["levelNumber"]): item["levelName"] for item in self.levels
@@ -164,14 +165,16 @@ class KlassVersion:
 
     @staticmethod
     def get_variant(
-        variant_id: str, select_level: int = 0, language: str = "nb"
+        variant_id: str | int,
+        select_level: int | None = None,
+        language: Language = "nb",
     ) -> KlassVariant:
         """Get a specific variant.
 
         Args:
-            variant_id (str): The ID of the variant.
-            select_level (int): The level of the variant to keep in the data. Setting to 0 keeps all levels.
-            language (str): The language of the variant.
+            variant_id: The ID of the variant.
+            select_level: The level of the variant to keep in the data. Setting to 0 keeps all levels.
+            language: The language of the variant.
 
         Returns:
             KlassVariant: A variant object with the specified ID and language.
@@ -263,41 +266,67 @@ class KlassVersion:
         return tables
 
     @staticmethod
+    @overload
     def get_correspondence(
-        correspondence_id: str = "",
-        source_classification_id: str = "",
-        target_classification_id: str = "",
-        from_date: str = "",
-        to_date: str = "",
+        correspondence_id: str | int = ...,
+        source_classification_id: None = ...,
+        target_classification_id: None = ...,
+        from_date: None = ...,
+        to_date: None = ...,
+        contain_quarter: int = ...,
+        language: Language = ...,
+        include_future: bool = ...,
+    ) -> KlassCorrespondence: ...
+
+    @staticmethod
+    @overload
+    def get_correspondence(
+        correspondence_id: None = ...,
+        source_classification_id: str | int = ...,
+        target_classification_id: str | int = ...,
+        from_date: str = ...,
+        to_date: str | None = ...,
+        contain_quarter: int = ...,
+        language: Language = ...,
+        include_future: bool = ...,
+    ) -> KlassCorrespondence: ...
+
+    @staticmethod
+    def get_correspondence(
+        correspondence_id: str | int | None = None,
+        source_classification_id: str | int | None = None,
+        target_classification_id: str | int | None = None,
+        from_date: str | None = None,
+        to_date: str | None = None,
         contain_quarter: int = 0,
-        language: str = "nb",
+        language: Language = "nb",
         include_future: bool = False,
     ) -> KlassCorrespondence:
         """Get a specific correspondence.
 
         Args:
-            correspondence_id (str): The ID of the correspondence.
-            source_classification_id (str): The ID of the source classification.
-            target_classification_id (str): The ID of the target classification.
-            from_date (str): The start date of the correspondence.
-            to_date (str): The end date of the correspondence.
-            contain_quarter (int): The number of quarters the correspondence should contain.
-            language (str): The language of the correspondence. "nb", "nn" or "en".
-            include_future (bool): If the correspondence should include future correspondences.
+            correspondence_id: The ID of the correspondence.
+            source_classification_id: The ID of the source classification.
+            target_classification_id: The ID of the target classification.
+            from_date: The start date of the correspondence.
+            to_date: The end date of the correspondence.
+            contain_quarter: The number of quarters the correspondence should contain.
+            language: The language of the correspondence. "nb", "nn" or "en".
+            include_future: If the correspondence should include future correspondences.
 
         Returns:
             KlassCorrespondence: A correspondence object with the specified ID, language, and dates.
         """
         return KlassCorrespondence(
-            correspondence_id=correspondence_id,
-            source_classification_id=source_classification_id,
-            target_classification_id=target_classification_id,
-            from_date=from_date,
-            to_date=to_date,
+            correspondence_id=correspondence_id,  # type: ignore [arg-type]
+            source_classification_id=source_classification_id,  # type: ignore [arg-type]
+            target_classification_id=target_classification_id,  # type: ignore [arg-type]
+            from_date=from_date,  # type: ignore [arg-type]
+            to_date=to_date,  # type: ignore [arg-type]
             contain_quarter=contain_quarter,
             language=language,
             include_future=include_future,
-        )
+        )  # type: ignore [misc]
 
     def get_all_correspondences(self) -> list[KlassCorrespondence]:
         """Get all correspondences of version as a list of KlassCorrespondences.
